@@ -68,14 +68,14 @@ struct Killbots::Coordinator::AnimationStage {
 
 Killbots::Coordinator::Coordinator(QObject *parent)
     : QObject(parent),
-      m_engine(0),
-      m_scene(0),
-      m_roundDisplay(0),
-      m_scoreDisplay(0),
-      m_enemyCountDisplay(0),
-      m_energyDisplay(0),
-      m_unqueuedPopup(0),
-      m_queuedPopup(0),
+      m_engine(nullptr),
+      m_scene(nullptr),
+      m_roundDisplay(nullptr),
+      m_scoreDisplay(nullptr),
+      m_enemyCountDisplay(nullptr),
+      m_energyDisplay(nullptr),
+      m_unqueuedPopup(nullptr),
+      m_queuedPopup(nullptr),
       m_timeLine(1000, this),
       m_busyAnimating(false),
       m_newGameRequested(false),
